package com.ruoyi.inspection.mapper;

import java.util.List;

import com.ruoyi.inspection.domain.InspectionAbnormal;

/**
 * 巡检异常Mapper接口
 *
 * @author LSD
 * @date 2025-10-24
 */
public interface InspectionAbnormalMapper {
    /**
     * 查询巡检异常
     *
     * @param id 巡检异常主键
     * @return 巡检异常
     */
    public InspectionAbnormal selectInspectionAbnormalById(Long id);

    /**
     * 查询巡检异常列表
     *
     * @param inspectionAbnormal 巡检异常
     * @return 巡检异常集合
     */
    public List<InspectionAbnormal> selectInspectionAbnormalList(InspectionAbnormal inspectionAbnormal);

    /**
     * 新增巡检异常
     *
     * @param inspectionAbnormal 巡检异常
     * @return 结果
     */
    public int insertInspectionAbnormal(InspectionAbnormal inspectionAbnormal);

    /**
     * 修改巡检异常
     *
     * @param inspectionAbnormal 巡检异常
     * @return 结果
     */
    public int updateInspectionAbnormal(InspectionAbnormal inspectionAbnormal);

    /**
     * 删除巡检异常
     *
     * @param id 巡检异常主键
     * @return 结果
     */
    public int deleteInspectionAbnormalById(Long id);

    /**
     * 批量删除巡检异常
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInspectionAbnormalByIds(Long[] ids);
}
